@@ -25,9 +25,6 @@
 
 - (void)showDocumentMenuViewController:(id)sender
 {
-    if (!@available(iOS 8, *))
-        return;
-
     UIDocumentMenuViewController *importMenu = [[UIDocumentMenuViewController alloc] initWithDocumentTypes:@[(id)kUTTypeAudiovisualContent] inMode:UIDocumentPickerModeImport];
     importMenu.delegate = self;
 
